@@ -1,14 +1,14 @@
-use crate::{
-    Attribute, shadow_gpu::BufferHandle, webgl::buffer::BufferUsageHint,
-};
+use crate::{shadow_gpu::BufferHandle, webgl::buffer::BufferUsageHint, Attribute};
 use std::marker::PhantomData;
 
+#[allow(clippy::len_without_is_empty)]
 pub trait BufferLike<T: Attribute> {
     fn get_buffer(&self) -> Option<BufferHandle>;
 
     fn len(&self) -> usize;
 }
 
+#[derive(Clone)]
 pub struct Buffer<T: Attribute> {
     handle: BufferHandle,
     _ph: PhantomData<T>,
@@ -25,6 +25,10 @@ impl<T: Attribute> Buffer<T> {
         }
     }
 
+    pub fn new_empty(usage_hint: BufferUsageHint) -> Self {
+        Self::new(Vec::new(), usage_hint)
+    }
+
     pub fn set_data(&self, data: Vec<T>) {
         self.handle.set_data(data);
     }
