@@ -1,5 +1,5 @@
+use crate::{state::StateDescriptor, webgl::types::SizedDataType};
 use std::collections::{BTreeMap, HashMap};
-use crate::webgl::types::SizedDataType;
 
 use super::{program::ProgramHandle, BufferHandle, UniformHandle, UniformValue};
 
@@ -20,4 +20,5 @@ pub struct GpuState {
     pub program: Option<ProgramHandle>,
     pub buffers: BTreeMap<BufferHandle, Vec<BufferBinding>>,
     pub uniforms: HashMap<UniformHandle, UniformValue>,
+    pub globals: StateDescriptor,
 }
