@@ -1,10 +1,20 @@
-use std::{error::Error, fmt::{Display, Debug}, marker::PhantomData, any::type_name};
+use std::{
+    any::type_name,
+    error::Error,
+    fmt::{Debug, Display},
+    marker::PhantomData,
+};
 
 struct UnexpectedValue<T>(u32, PhantomData<T>);
 
 impl<T> Display for UnexpectedValue<T> {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(f, "Unexpected value for type {:?}: {}", type_name::<T>(), self.0)
+        write!(
+            f,
+            "Unexpected value for type {:?}: {}",
+            type_name::<T>(),
+            self.0
+        )
     }
 }
 
@@ -15,4 +25,3 @@ impl<T> Debug for UnexpectedValue<T> {
 }
 
 impl<T> Error for UnexpectedValue<T> {}
-
